This module defines the Sequence type and it is the core of this library
Modules
- states
- This module defines the states of the Sequence type
- types
- This module defines type aliases for the sequence module
Structs
- Sequence
- A type that represents a sequence. the Sequence type uses Vec to store its elements, so the max number of elements it can hold is std::usize::MAX.
Traits
- Shared
Sequence Behavior - Shared behavior between sequences that requires initial elements and sequences that do not require initial elements.