Module seqgen::sequence

source ·
This module defines the Sequence type and it is the core of this library

Structs

  • A type that represents a sequence. the Sequence type uses Vec to store its elements, so the max number of elements it can hold is std::usize::MAX.

Traits

  • Shared behavior between sequences with initial element and sequences that do not require initial element.