This module defines the Sequence type and it is the core of this library
Modules
- This module defines the states of the Sequence type
- This module defines type aliases
Structs
- A type that represents a sequence. the Sequence type uses Vec to store its elements, so the max number of elements it can hold is std::usize::MAX, that’s enough for most of us :)
Traits
- Shared behavior between Sequence